@@ -26,8 +26,9 @@ class ConnectionConfig(BaseModel):
 
 class Remote(BaseModel):
     bucket: str
-    connection_config: Union[ConnectionConfig, HttpUrl]
-    version: int = Field(None, description='Version of the S3 data structure.')
+    connection_config: ConnectionConfig = None
+    public_url: HttpUrl = None
+    version: int = Field(..., description='Version of the S3 data structure.')
     description: str = Field(None, description='Description of the datasets that are contained within the remote.')
 
 
